@@ -36,11 +36,29 @@ MYPKGOPTIONS <- settings::options_manager(
       scientific <- sapply(x, function(x)is.numeric(x) && is.finite(x) && x != 0 && abs(log10(abs(x))) > 3)
 
       return(mapply(format, x = x, scientific = scientific,
-             MoreArgs = list( digits = 2, trim = TRUE, nsmall = 0)))
+             MoreArgs = list(digits = 2, trim = TRUE, nsmall = 0)))
     },
   format_percent = function(x){
     return(sapply(x, format, scientific = FALSE, digits = 2, trim = TRUE, nsmall = 0))
-    }
+    },
+  get_alias.default = function(x, ...){
+    attr(x, "alias", exact = TRUE)
+  },
+  modifiy_colnames_without_alias = function(x, ...){
+    gsub(x, pattern = "_", replacement = " ")},
+  get_alias.labelled = function(x, ...){
+
+    out <- attr(x, "label", exact = TRUE)
+
+    Units <- attr(x, "units", exact = TRUE)
+
+    out = if(!is.null(Units)){
+      paste0(out, " [", Units, "]")}else{out}
+
+    return(out)
+
+  }
+
 
 )
 # User function that gets exported:
@@ -146,7 +164,15 @@ MYPKGOPTIONS <- settings::options_manager(
 #'    This functions is called by \code{\link{format_statistics}} and \code{\link{format_tests}} for number,
 #'    that are not p-values or percentages.}
 #'
+#'    \item{\code{get_alias.default}}{: A function with one argument \code{x} and \code{...} returning a character or \code{NULL}.
+#'    This functions is called by \code{get_alias} and \code{create_alias_mapping} to retrieve alternative Variable names to print
+#'    in the table.}
 #'
+#'    \item{\code{get_alias.labelled}}{: A function with one argument \code{x} and \code{...}, that must return a character.
+#'    This functions is called by \code{get_alias} on the columns that have class labelled.}
+#'
+#'    \item{\code{modifiy_colnames_without_alias}}{: A function with one argument \code{x} and \code{...} returning a character.
+#'    This functions is called by \code{create_alias_mapping} on the columns that have \code{is.NULL(get_alias(x))}}
 #' }
 #'
 #' @examples
